pub struct BasicScanner { /* private fields */ }Expand description
A basic scanner implementation for YAML tokenization
Implementations
Sourceimpl BasicScanner
impl BasicScanner
Sourcepub fn with_limits(input: String, limits: Limits) -> Self
pub fn with_limits(input: String, limits: Limits) -> Self
Create a new scanner with custom resource limits
Sourcepub fn new_eager(input: String) -> Self
pub fn new_eager(input: String) -> Self
Create a new scanner with eager token scanning (for compatibility)
Sourcepub fn new_eager_with_limits(input: String, limits: Limits) -> Self
pub fn new_eager_with_limits(input: String, limits: Limits) -> Self
Create a new scanner with eager token scanning and custom limits
Sourcepub fn new_with_comments(input: String) -> Self
pub fn new_with_comments(input: String) -> Self
Create a new scanner with comment preservation enabled
Sourcepub fn new_with_comments_and_limits(input: String, limits: Limits) -> Self
pub fn new_with_comments_and_limits(input: String, limits: Limits) -> Self
Create a new scanner with comments and custom limits
Sourcepub fn new_eager_with_comments(input: String) -> Self
pub fn new_eager_with_comments(input: String) -> Self
Create a new scanner with eager scanning and comment preservation
Sourcepub const fn detected_indent_style(&self) -> Option<&IndentStyle>
pub const fn detected_indent_style(&self) -> Option<&IndentStyle>
Get the detected indentation style from the document
Sourcepub const fn has_scanning_error(&self) -> bool
pub const fn has_scanning_error(&self) -> bool
Check if there was a scanning error
Sourcepub fn take_scanning_error(&mut self) -> Option<Error>
pub fn take_scanning_error(&mut self) -> Option<Error>
Get the scanning error if any